# django-sessioninfo

* https://pypi.python.org/pypi/django-sessioninfo
* https://github.com/arteria/django-sessioninfo 

## Quickstart

 


## Features

* Give detailled info about the sessions of your users.
* Find users by session key.
* Logging out users mechanism.

